==> haskell-hslua-objectorientation-2.3.1-42.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-objectorientation
version:              2.3.1
visibility:           public
id:                   hslua-objectorientation-2.3.1-B9MwAAb5OzV1notznHofI0
key:                  hslua-objectorientation-2.3.1-B9MwAAb5OzV1notznHofI0
license:              MIT
copyright:            © 2021-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  723b3c564223cbf7722e6a6d322bb933
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-objectorientation-2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-objectorientation-2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-objectorientation-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.1-B9MwAAb5OzV1notznHofI0
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.7 hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
    hslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH
    hslua-typing-0.1.1-4crtxjwFkdc2BMYn78fMvp mtl-2.3.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-objectorientation-2.3.1-43-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-objectorientation
version:              2.3.1
visibility:           public
id:                   hslua-objectorientation-2.3.1-BeXpt3VargyDZJB8AIbZnR
key:                  hslua-objectorientation-2.3.1-BeXpt3VargyDZJB8AIbZnR
license:              MIT
copyright:            © 2021-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  7e2b03a70f1326e296109bc92468ee1d
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-objectorientation-2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-objectorientation-2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-objectorientation-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.1-BeXpt3VargyDZJB8AIbZnR
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.7 hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
    hslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD
    hslua-typing-0.1.1-4nrS70YStomG6eM4zMy5zG mtl-2.3.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
